@@ -1,9 +1,9 @@
 class AutoSolveConstants:
     #NAMES
     HOSTNAME = "rabbit.autosolve.io"
-    VHOST = "TBD"
-    DIRECT_EXCHANGE = "exchanges.autosolve.direct"
-    FANOUT_EXCHANGE = "exchanges.autosolve.fanout"
+    VHOST = "oneclick"
+    DIRECT_EXCHANGE = "exchanges.direct"
+    FANOUT_EXCHANGE = "exchanges.fanout"
     RECEIVER_QUEUE_NAME = "queues.response.direct"
 
     #ROUTES
@@ -12,10 +12,9 @@ class AutoSolveConstants:
     TOKEN_RECEIVE_ROUTE = "routes.response.token"
     CANCEL_RECEIVE_ROUTE = "routes.response.token.cancel"
 
-
     #CONFIG
     AUTO_DELETE = False
-    DURABLE = False
+    DURABLE = True
     AUTO_ACK = True
     EXCLUSIVE = False
 
@@ -25,6 +24,7 @@ class AutoSolveConstants:
     INPUT_VALUE_ERROR = "Input value for access_token is invalid or client_key/api_key are not set"
     CONNECTION_LOST_ERROR = "Connection lost, manual recovery expected"
     CONNECTION_REESTABLISH_FAILED = "Connection could not be re-established"
+    CONNECTION_ERROR_INIT = "Connection error when initializing. Please retry"
 
     #STATUS
     SUCCESS = "info"
