@@ -23,7 +23,7 @@ try:
         "api_key": "clientApiKey",
         "client_key": "yourClientKey",
         "receiver_function" : receiver_function,
-        "cancel_function" : cancel_function,
+        "should_alert_on_cancel" : cancel_function,
         "debug" : True
     })
 
